build_extensible_array_at

Function build_extensible_array_at 

pub fn build_extensible_array_at(
    chunks: &[WrittenChunk],
    offset_size: u8,
    length_size: u8,
    has_filters: bool,
    ea_base_address: u64,
) -> Vec<u8> 
Build a complete Extensible Array at a known absolute address.

For simplicity, we put all elements inline in the index block when the number of chunks is small (up to idx_blk_elmts), otherwise use inline + direct data blocks.