read_array_flat

Function read_array_flat 

pub fn read_array_flat(
    raw: &[u8],
    datatype: &Datatype,
) -> Result<(Vec<u8>, Datatype, Vec<u32>), FormatError>
Read array-typed dataset elements, returning the raw base-type data.

For an array type with dimensions [D1, D2, …] and base type T, each dataset element contains D1D2… values of type T. This function returns the raw bytes as a flat buffer that can be converted with read_as_f64, read_as_i32, etc. using the base type.