read_raw_data_cached

Function read_raw_data_cached 

pub fn read_raw_data_cached(
    file_data: &[u8],
    layout: &DataLayout,
    dataspace: &Dataspace,
    datatype: &Datatype,
    pipeline: Option<&FilterPipeline>,
    offset_size: u8,
    length_size: u8,
    cache: &ChunkCache,
) -> Result<Vec<u8>, FormatError>
Read raw bytes with chunk cache support.

For chunked layouts the cache is used to avoid repeated B-tree traversals and to cache decompressed chunk data. For compact and contiguous layouts this behaves identically to read_raw_data_full.