pub struct CompoundFieldData {
pub name: String,
pub datatype: Datatype,
pub raw_data: Vec<u8>,
}Expand description
A single field extracted from compound data, containing the raw bytes for that field across all elements.
Fields
name: StringField name.
datatype: DatatypeDatatype of this field.
raw_data: Vec<u8>Raw bytes for this field across all elements (len = num_elements * field_type_size).