ExtensibleArrayHeader

Struct ExtensibleArrayHeader 

pub struct ExtensibleArrayHeader {
    pub client_id: u8,
    pub element_size: u8,
    pub max_nelmts_bits: u8,
    pub idx_blk_elmts: u8,
    pub min_dblk_nelmts: u8,
    pub super_blk_min_nelmts: u8,
    pub max_dblk_nelmts_bits: u8,
    pub num_elements: u64,
    pub index_block_address: u64,
}
Parsed Extensible Array header (AEHD).

Fields

client_id: u8

Client ID: 0 = non-filtered chunks, 1 = filtered chunks.

element_size: u8

Size of each array element in bytes.

max_nelmts_bits: u8

Max number of elements bits (log2 of the max number of data block elements per page).

idx_blk_elmts: u8

Number of elements in the index block.

min_dblk_nelmts: u8

Minimum number of data block elements.

super_blk_min_nelmts: u8

Minimum number of elements in a super block.

max_dblk_nelmts_bits: u8

Max number of data block elements bits.

num_elements: u64

Total number of elements stored.

index_block_address: u64

Address of the index block.

Implementations

Source

impl ExtensibleArrayHeader

pub fn parse( file_data: &[u8], offset: usize, offset_size: u8, length_size: u8, ) -> Result<Self, FormatError>

Parse an Extensible Array header from file data at the given offset.

pub fn serialized_size(offset_size: u8, length_size: u8) -> usize

Compute the size of this header in bytes (for write support).