read_fixed_array_chunks

Function read_fixed_array_chunks 

pub fn read_fixed_array_chunks(
    file_data: &[u8],
    header: &FixedArrayHeader,
    dataset_dims: &[u64],
    chunk_dimensions: &[u32],
    element_size: u32,
    offset_size: u8,
    _length_size: u8,
) -> Result<Vec<ChunkInfo>, FormatError>
Read chunk records from a Fixed Array data block.

Returns a Vec<ChunkInfo> with one entry per allocated chunk. chunk_dimensions should be the spatial chunk dims only (not including the element-size dim). element_size is the datatype size in bytes.