LocalHeap

Struct LocalHeap 

pub struct LocalHeap {
    pub data_segment_size: u64,
    pub free_list_head_offset: u64,
    pub data_segment_address: u64,
}
Parsed HDF5 Local Heap header.

Fields

data_segment_size: u64

Size of the data segment in bytes.

free_list_head_offset: u64

Offset of the free list head within the data segment.

data_segment_address: u64

File address of the data segment.

Implementations

Source

impl LocalHeap

pub fn parse( file_data: &[u8], offset: usize, offset_size: u8, length_size: u8, ) -> Result<LocalHeap, FormatError>

Parse a local heap header at the given offset in the file data.

pub fn read_string( &self, file_data: &[u8], string_offset: u64, ) -> Result<String, FormatError>

Read a null-terminated string from the heap’s data segment at the given byte offset.