pub struct SymbolTableEntry {
pub link_name_offset: u64,
pub object_header_address: u64,
pub cache_type: u32,
pub scratch_pad: [u8; 16],
}Expand description
A single entry in a Symbol Table Node (SNOD).
Fields
link_name_offset: u64Byte offset of the link name in the local heap.
object_header_address: u64Address of the child object’s header.
cache_type: u32Cache type: 0=none, 1=group, 2=symbolic link.
scratch_pad: [u8; 16]16-byte scratch pad (cached data).