pub fn parse_shared_ref(
data: &[u8],
offset_size: u8,
) -> Result<SharedMessageRef, FormatError>Expand description
Parse a shared message reference from the message data.
When the shared flag is set on a message, the data contains a reference instead of the actual message content.