pub fn resolve_shared_message(
file_data: &[u8],
shared_ref: &SharedMessageRef,
target_msg_type: MessageType,
offset_size: u8,
length_size: u8,
) -> Result<Vec<u8>, FormatError>Expand description
Resolve a shared message to its actual message data.
For type 1/3 (shared in another object header), reads the target object header and finds the message of the specified type. For type 2 (SOHM), uses the fractal heap from the SOHM table.